#
# spec file for package arp-scan
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without caps
Name:           arp-scan
Version:        1.10.0
Release:        1.9
Summary:        ARP scanning and fingerprinting tool
# strlcpy.c and strlcat.c have ISC header and embeded {getopt,obstack}.{c,h} has LGPL-2.1
License:        GPL-3.0-only AND LGPL-2.1-only AND ISC
Group:          Productivity/Networking/Security
URL:            https://github.com/royhills/arp-scan
Source:         https://github.com/royhills/arp-scan/releases/download/%{version}/%{name}-%{version}.tar.gz
BuildRequires:  perl-macros
BuildRequires:  pkgconfig
BuildRequires:  perl(LWP::Simple)
BuildRequires:  pkgconfig(libpcap) >= 1.5.0
Requires:       perl(LWP::Simple)
%{perl_requires}
%if 0%{with caps}
# pre-installed in build root, but make explicit anyway
BuildRequires:  pkgconfig(libcap)
%endif

%description
arp-scan is a command-line tool that uses the ARP protocol to discover and fingerprint IP hosts on the local network.

%define debug_package_requires %{name} = %{version}-%{release}

%prep
%autosetup -p1

%build
%configure \
%if %{with caps}
	--with-libcap=yes \
%else
# defaults to auto
	--with-libcap=no \
%endif
	%{nil}
%make_build

%check
%make_build check

%install

%make_install
sed -i "s|env ||g" %{buildroot}%{_bindir}/*

%files
%license COPYING
%doc AUTHORS ChangeLog NEWS README TODO
%{_bindir}/*
%{_datadir}/arp-scan
%dir %{_sysconfdir}/arp-scan
%config(noreplace) %{_sysconfdir}/arp-scan/mac-vendor.txt
%{_mandir}/man1/*.1%{?ext_man}
%{_mandir}/man5/*.5%{?ext_man}

%changelog
* Wed Mar  1 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.10.0
  * Support for POSIX.1e capabilities. Administrators can set
    cap_net_raw+p on the arp-scan binaries to allow non-root users
    to run arp scan if desired
  * MAC/Vendor file layout changed. /etc/arp-scan/mac-vendor.txt
    allows for local configuration
- build with upstream tarball
* Mon Dec  5 2022 Dirk Müller <dirk@matrix>
- update to 1.9.8:
  - Allow the use of Linux IP aliases such as eth0:0 for the interface name.
  - Permit regular MAC addresses e.g. 00:0c:29:b9:43:1b in mac-vendor.txt.
  - --limit=n option exits after n of hosts have responded, exit 1 for <n
  - --resolve option to resolve responding IP addresses to hostnames
  - Potential buffer overrun in unmarshal_arp_pkt().
  - arp-scan aborts with EAGAIN on busy network or using high bandwidth
  - late ARP responses could sometimes be incorrectly flagged as duplicate
  - Updated IEEE URLs in download perl scripts.
  - Updated source for Mersenne RNG and replacement strlcat/strlcpy & getopt.
  - Updated for compatability with autoconf 2.71
  - "make distcheck" works now
  - Number of responding hosts reported no longer counts duplicate packets.
  - Many typos corrected and edge cases fixed.
  - CI framework migrated from travis-ci to github actions.
  - Several new tests for "make check"
* Thu Nov 14 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.9.7:
  * Internal changes only
* Fri Oct 25 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.9.6 (boo#1154552):
  * Use libpcap function pcap_set_immediate_mode() instead of ioctl
    calls to ensure packets are delivered immediately. This means
    that arp-scan now requires libpcap 1.5.0 or later and will
    not work with earlier libpcap versions
* Tue Mar  5 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.9.5:
  * Updated IEEE OUI and IAB MAC/Vendor files.
  * Added new --plain (-x) option to surpress printing of header
    and footer text, and only display one output line for each
    responding host.
  * Use LWP::UserAgent instead of LWP::Simple in get-oui and
    get-iab to enable the raw content to be obtained, which avoids
    Unicode/UTF-8 issues.
  * Added arp-finherprint patterns for WIZnet W5100 and Cisco IOS
    15.0.
- Drop no longer needed arp-scan-avoid-crash.patch
* Mon May 21 2018 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Adjust dependencies
* Wed May 11 2016 meissner@suse.com
- arp-scan-avoid-crash.patch: avoid crash when trying capture as
  user (bsc#978596)
* Sun Feb 14 2016 mpluskal@suse.com
- Update project and download url
* Thu May  7 2015 mpluskal@suse.com
- Update licensing information
* Thu May  7 2015 mpluskal@suse.com
- Update to 1.9
- Cleanup spec file with spec-cleaner
- Update project url
- Use url for source
* Mon Mar  7 2011 pascal.bleser@opensuse.org
- update to 1.8:
  * the IEEE OUI and IAB files were updated
  * support was added for trailer ARP replies
  * support for LLC/SNAP packets with the 802.1Q tag was added
  * full help output is no longer displayed for usage errors
  * the license was changed from GPL v2 to v3
  * a DoS warning was added to the manpage and help output
  * new arp fingerprints were added
  * gcc compiler security options were enabled
  * the Perl scripts were modified to work on systems where the perl executable
    is not in /usr/bin
  * various minor bugfixes and improvements were made
* Fri Mar 20 2009 bitshuffler #suse@irc.freenode.org
- Initial RPM
